@@ -30,51 +30,19 @@ class PostEndpoints:
         :param data: Fields that are allowed are listed in allowed fields array. Update this whenever necessary
         :return: status code for request and optional error message
         """
-        allowed_fields = ['cost_carrier', 'org_unit_id', 'cost_center', 'salutation', 'last_name', 'first_name', 'name_prefix', 'second_name_prefix',
-                          'middle_name', 'initials', 'second_title', 'date_of_birth', 'language', 'nationality', 'title', 'gender']
-        required_fields = ['employment_status', 'afas_employee_id', 'employee_start_date', 'end_date', 'action', 'reason', 'position_id', 'employee_group',
-                           'personal_area', 'personal_subarea', 'employee_subgroup']
+        allowed_fields = []
+        required_fields = ["Afasemployeenumber", "Employeenumber", "Startdate", "Enddate", "Actiontype",
+                           "Reasonforaction", "Employmentstatus","Companycode", "Personnelarea", "Personnelsubarea",
+                           "Employeegroup", "Employeesubgroup", "OrgunitID", "PositionID", "Costcenter", "Salutation",
+                           "Lastname", "Firstname", "Nameprefix", "Secondnameprefix", "NameatBirth", "Initials",
+                           "Othertitle", "Dateofbirth", "Communicationlanguage", "Nationality", "Title", "Gender",
+                           "ExternalEmployeesubgroup"]
 
         self.__check_fields(data=data, required_fields=required_fields, allowed_fields=allowed_fields)
 
-        base_body = {
-            "Afasemployeenumber": data['afas_employee_id'],
-            "Employeenumber": "00000000",
-            "Startdate": data['employee_start_date'],
-            "Enddate": "9999-12-31",
-            "Actiontype": data['action'],
-            "Reasonforaction": data['reason'],
-            "Employmentstatus": data['employment_status'],
-            "Personnelarea": data['personal_area'],
-            "Personnelsubarea": data['personal_subarea'],
-            "Employeegroup": data['employee_group'],
-            "Employeesubgroup": data['employee_subgroup'],
-            "PositionID": data['position_id']
-        }
-        fields_to_update = {}
-
-        # Add fields that you want to update a dict (adding to body itself is too much text)
-        fields_to_update.update({"Companycode": data['cost_carrier']}) if 'cost_carrier' in data else fields_to_update
-        fields_to_update.update({"OrgunitID": data['org_unit_id']}) if 'org_unit_id' in data else fields_to_update
-        fields_to_update.update({"Costcenter": data['cost_center']}) if 'cost_center' in data else fields_to_update
-        fields_to_update.update({"Salutation": data['salutation']}) if 'salutation' in data else fields_to_update
-        fields_to_update.update({"Lastname": data['last_name']}) if 'last_name' in data else fields_to_update
-        fields_to_update.update({"Firstname": data['first_name']}) if 'first_name' in data else fields_to_update
-        fields_to_update.update({"Nameprefix": data['name_prefix']}) if 'name_prefix' in data else fields_to_update
-        fields_to_update.update({"Secondnameprefix": data['second_name_prefix']}) if 'second_name_prefix' in data else fields_to_update
-        fields_to_update.update({"Middlename": data['middle_name']}) if 'middle_name' in data else fields_to_update
-        fields_to_update.update({"Initials": data['initials']}) if 'initials' in data else fields_to_update
-        fields_to_update.update({"Othertitle": data['second_title']}) if 'second_title' in data else fields_to_update
-        fields_to_update.update({"Dateofbirth": data['date_of_birth']}) if 'date_of_birth' in data else fields_to_update
-        fields_to_update.update({"Communicationlanguage": data['language']}) if 'language' in data else fields_to_update
-        fields_to_update.update({"Nationality": data['nationality']}) if 'nationality' in data else fields_to_update
-        fields_to_update.update({"Title": data['title']}) if 'title' in data else fields_to_update
-        fields_to_update.update({"Gender": data['gender']}) if 'gender' in data else fields_to_update
-
-        fields_to_update.update(overload_fields) if overload_fields is not None else ''
+        base_body = data
 
         # Update the request body with update fields
-        base_body.update(fields_to_update)
         response = self.base_class.post_data(uri='MasterActionPost/*', data=base_body, return_key='Employeenumber')
         return response
 
